static char vis_pixel_doc[]="
Draw a pixel.

Parameters: (i,i)|(i,i,i)|(i,i,[f,f,f]) : the pixel coordinates with an optional
            color (foreground color is used by default).
Return:     None
";
static PyObject* vis_pixel(GGIVisualObject*self, PyObject*args) {
	int x,y;
	ggi_pixel p;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 2:
		if(!PyArg_ParseTuple(args, "ii",&x,&y))
			return NULL;
		if(ggiDrawPixel(self->vis,x,y)) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawPixel failed");
			return NULL;
		}
		break;
	case 3:
		if(!PyArg_ParseTuple(args, "iiO",&x,&y,&o))
			return NULL;
		if(pyggi_get_pixel(o,&p,self->vis))
			return NULL;
		if(ggiPutPixel(self->vis,x,y,p)) {
			PyErr_SetString(PyExc_SystemError,"ggiPutPixel failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}

static char vis_line_doc[]="
Draw a line.

Parameters: (i,i,i,i)|(i,i,i,i,i)|(i,i,i,i,[f,f,f]): the line endpoints with an
            optional color (foreground color is used by default).
Return:     None
";
static PyObject* vis_line(GGIVisualObject *self, PyObject *args) {
	int x1,y1,x2,y2;
	ggi_pixel fg;
	ggi_pixel p;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 4:
		if(!PyArg_ParseTuple(args, "iiii",&x1,&y1,&x2,&y2))
			return NULL;
		if(ggiDrawLine(self->vis,x1,y1,x2,y2)) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawLine failed");
			return NULL;
		}
		break;
	case 5:
		if(!PyArg_ParseTuple(args, "iiiiO",&x1,&y1,&x2,&y2,&o))
			return NULL;
		if(pyggi_get_pixel(o,&p,self->vis))
			return NULL;
		ggiGetGCForeground(self->vis,&fg);
		ggiSetGCForeground(self->vis,p);
		x1=ggiDrawLine(self->vis,x1,y1,x2,y2);
		ggiSetGCForeground(self->vis,fg);
		if(x1) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawLine failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}

static char vis_hline_doc[]="
Draw an horizontal line.

Parameters: (i,i,i)|(i,i,i,i)|(i,i,i,[f,f,f]): the line startpoint and length, with an
            optional color (foreground color is used by default).
Return:     None
";
static PyObject* vis_hline(GGIVisualObject *self, PyObject *args) {
	int x1,y1,l;
	ggi_pixel fg;
	ggi_pixel p;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 3:
		if(!PyArg_ParseTuple(args, "iii",&x1,&y1,&l))
			return NULL;
		if(ggiDrawHLine(self->vis,x1,y1,l)) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawHLine failed");
			return NULL;
		}
		break;
	case 4:
		if(!PyArg_ParseTuple(args, "iiiO",&x1,&y1,&l,&o))
			return NULL;
		if(pyggi_get_pixel(o,&p,self->vis))
			return NULL;
		ggiGetGCForeground(self->vis,&fg);
		ggiSetGCForeground(self->vis,p);
		x1=ggiDrawHLine(self->vis,x1,y1,l);
		ggiSetGCForeground(self->vis,fg);
		if(x1) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawHLine failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}


static char vis_vline_doc[]="
Draw a vertical line.

Parameters: (i,i,i)|(i,i,i,i)|(i,i,i,[f,f,f]): the line startpoint and length, with an
            optional color (foreground color is used by default).
Return:     None
";
static PyObject* vis_vline(GGIVisualObject *self, PyObject *args) {
	int x1,y1,l;
	ggi_pixel fg;
	ggi_pixel p;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 3:
		if(!PyArg_ParseTuple(args, "iii",&x1,&y1,&l))
			return NULL;
		if(ggiDrawVLine(self->vis,x1,y1,l)) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawVLine failed");
			return NULL;
		}
		break;
	case 4:
		if(!PyArg_ParseTuple(args, "iiiO",&x1,&y1,&l,&o))
			return NULL;
		if(pyggi_get_pixel(o,&p,self->vis))
			return NULL;
		ggiGetGCForeground(self->vis,&fg);
		ggiSetGCForeground(self->vis,p);
		x1=ggiDrawVLine(self->vis,x1,y1,l);
		ggiSetGCForeground(self->vis,fg);
		if(x1) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawVLine failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}

static char vis_box_doc[]="
Draw a box.

Parameter: (i,i,i,i)|(i,i,i,i,i)|(i,i,i,i,[f,f,f]): the corner coords with an
           optional color (foreground color is used by default).
Return:    None
";
static PyObject* vis_box(GGIVisualObject *self, PyObject *args) {
	int x1,y1,x2,y2;
	ggi_pixel fg;
	ggi_pixel p;
	PyObject * o;

	switch(PyTuple_GET_SIZE(args)) {
	case 4:
		if(!PyArg_ParseTuple(args, "iiii",&x1,&y1,&x2,&y2))
			return NULL;
		if(ggiDrawBox(self->vis,x1,y1,x2,y2)) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawBox failed");
			return NULL;
		}
		break;
	case 5:
		if(!PyArg_ParseTuple(args, "iiiiO",&x1,&y1,&x2,&y2,&o))
			return NULL;
		if(pyggi_get_pixel(o,&p,self->vis))
			return NULL;
		ggiGetGCForeground(self->vis,&fg);
		ggiSetGCForeground(self->vis,p);
		x1=ggiDrawBox(self->vis,x1,y1,x2,y2);
		ggiSetGCForeground(self->vis,fg);
		if(x1) {
			PyErr_SetString(PyExc_SystemError,"ggiDrawBox failed");
			return NULL;
		}
		break;
	default:
		PyErr_SetString(PyExc_TypeError,"wrong parameters");
			return NULL;
	}
	Py_INCREF(Py_None);
	return Py_None;
}
